@@ -2,7 +2,7 @@ package Test2::Harness::Job::Runner::Fork;
 use strict;
 use warnings;
 
-our $VERSION = '0.001001'; # TRIAL
+our $VERSION = '0.001003'; # TRIAL
 
 use Scalar::Util qw/openhandle/;
 use Test2::Util qw/clone_io CAN_REALLY_FORK/;
@@ -12,9 +12,6 @@ sub viable {
     my $class = shift;
     my ($test) = @_;
 
-    die "Test::Builder was preloaded, that is not supported"
-        if $INC{'Test/Builder.pm'};
-
     return 0 unless CAN_REALLY_FORK();
 
     return 0 if $ENV{HARNESS_PERL_SWITCHES};
@@ -32,9 +29,6 @@ sub run {
     my $class = shift;
     my ($test) = @_;
 
-    die "Test::Builder was preloaded, that is not supported"
-        if $INC{'Test/Builder.pm'};
-
     my $pid = fork();
     die "Failed to fork: $!" unless defined $pid;
 
@@ -90,7 +84,10 @@ sub run {
     # avoid child processes sharing the same seed value as the parent
     srand();
 
-    Test2::API::test2_post_prefork_reset() if $INC{'Test2/API.pm'};
+    if ($INC{'Test2/API.pm'}) {
+        Test2::API::test2_stop_preload();
+        Test2::API::test2_post_preload_reset();
+    }
 
     push @INC => @{$test->libs};
 
@@ -185,8 +182,6 @@ Test2::Harness::Job::Runner::Fork - Logic for running a test job by forking.
 
 =head1 DESCRIPTION
 
-=back
-
 =head1 SOURCE
 
 The source code repository for Test2-Harness can be found at
